==> nmrium-0.50.1.tgz: package/lib/component/1d/tool/XLabelPointer.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { useCallback } from 'react';
import { useBrushTracker } from '../../EventsTrackers/BrushTracker';
import { useMouseTracker } from '../../EventsTrackers/MouseTracker';
import { useChartData } from '../../context/ChartContext';
import { useScaleChecked } from '../../context/ScaleContext';
import { useFormatNumberByNucleus } from '../../hooks/useFormatNumberByNucleus';
import useSpectrum from '../../hooks/useSpectrum';
const style = {
    cursor: 'crosshair',
    transformOrigin: 'bottom right',
    position: 'absolute',
    top: '-18px',
    left: '-30px',
    pointerEvents: 'none',
    overflow: 'visible',
    userSelect: 'none',
};
function XLabelPointer() {
    const { height, width, margin } = useChartData();
    const activeSpectrum = useSpectrum(null);
    const { scaleX } = useScaleChecked();
    const position = useMouseTracker();
    const brushState = useBrushTracker();
    const format = useFormatNumberByNucleus(activeSpectrum?.info.nucleus);
    const getXValue = useCallback((xVal) => {
        if (activeSpectrum) {
            const xInvert = scaleX().invert(xVal);
            return format(xInvert);
        }
    }, [activeSpectrum, format, scaleX]);
    if (!activeSpectrum ||
        brushState.step === 'brushing' ||
        !position ||
        position.y < margin.top ||
        position.x < margin.left ||
        position.x > width - margin.right ||
        position.y > height - margin.bottom) {
        return null;
    }
    return (_jsx("div", { style: {
            ...style,
            transform: `translate(${position.x}px, ${position.y}px)`,
        }, children: _jsx("span", { children: getXValue(position.x) }) }, "xLabelPointer"));
}
export default XLabelPointer;

==> nmrium-0.55.0.tgz: package/lib/component/1d/tool/XLabelPointer.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { useBrushTracker } from '../../EventsTrackers/BrushTracker';
import { useMouseTracker } from '../../EventsTrackers/MouseTracker';
import { useChartData } from '../../context/ChartContext';
import { useScaleChecked } from '../../context/ScaleContext';
import { useFormatNumberByNucleus } from '../../hooks/useFormatNumberByNucleus';
import useSpectrum from '../../hooks/useSpectrum';
const style = {
    cursor: 'crosshair',
    position: 'absolute',
    paddingRight: '5px',
    pointerEvents: 'none',
    overflow: 'visible',
    userSelect: 'none',
};
function XLabelPointer() {
    const { height, width, margin } = useChartData();
    const activeSpectrum = useSpectrum(null);
    const { scaleX } = useScaleChecked();
    const position = useMouseTracker();
    const brushState = useBrushTracker();
    const format = useFormatNumberByNucleus(activeSpectrum?.info.nucleus);
    if (!activeSpectrum ||
        brushState.step === 'brushing' ||
        !position ||
        position.y < margin.top ||
        position.x < margin.left ||
        position.x > width - margin.right ||
        position.y > height - margin.bottom) {
        return null;
    }
    const x = scaleX().invert(position.x);
    return (_jsx("div", { style: {
            ...style,
            transform: `translate(${position.x}px, ${position.y}px) translate(-100%,-100%)`,
        }, children: _jsx("span", { children: format(x) }) }));
}
export default XLabelPointer;
